-- Obsidian
-- Move to ~/Notes/all
vim.api.nvim_create_user_command('MoveNoteToAll', function()
  local file = vim.fn.expand '%:p' -- Obtenir le chemin complet du fichier ouvert
  local target_dir = vim.fn.expand '~/Notes/all/' -- Résoudre le chemin du dossier cible

  -- Vérifier si le fichier existe
  if vim.fn.filereadable(file) == 1 then
    -- Utiliser une commande shell pour déplacer le fichier
    local cmd = 'mv ' .. vim.fn.shellescape(file) .. ' ' .. vim.fn.shellescape(target_dir)
    vim.fn.system(cmd)

    -- Vérifier si la commande s'est bien exécutée
    if vim.fn.filereadable(target_dir .. vim.fn.fnamemodify(file, ':t')) == 1 then
      -- Fermer le buffer après déplacement si le fichier a bien été déplacé
      vim.cmd 'bdelete!'
    else
      print "Erreur : Le fichier n'a pas été déplacé."
    end
  else
    print 'Impossible de déplacer : fichier non valide.'
  end
end, { nargs = 0 })

-- Delete note
vim.api.nvim_create_user_command('DeleteNote', function()
  local file = vim.fn.expand '%:p' -- Obtenir le chemin complet du fichier ouvert

  -- Vérifier si le fichier existe
  if vim.fn.filereadable(file) == 1 then
    -- Utiliser une commande shell pour supprimer le fichier
    local cmd = 'rm ' .. vim.fn.shellescape(file)
    vim.fn.system(cmd)

    -- Fermer le buffer après suppression
    vim.cmd 'bdelete!'
  else
    print 'Impossible de supprimer : fichier non valide.'
  end
end, { nargs = 0 })

-- Obsidian keymaps
vim.keymap.set('n', '<leader>on', '<cmd>ObsidianNew<CR>', { desc = '[N]ouvelle note' })
vim.keymap.set('n', '<leader>oj', '<cmd>ObsidianToday<CR>', { desc = 'Note [J]ournalière' })
vim.keymap.set('n', '<leader>ow', '<cmd>ObsidianDailies<CR>', { desc = '[W] Notes Journalières' })
vim.keymap.set('n', '<leader>oq', '<cmd>ObsidianQuickSwitch<CR>', { desc = '[Q]uick switch' })
vim.keymap.set('n', '<leader>os', '<cmd>ObsidianSearch<CR>', { desc = '[S]earch notes' })
vim.keymap.set('n', '<leader>ot', '<cmd>ObsidianNewFromTemplate<CR>', { desc = 'new from [T]emplate ' })
vim.keymap.set('n', '<leader>oa', '<cmd>ObsidianTags<CR>', { desc = 'T[a]gs picker' })
vim.keymap.set('n', '<leader>oc', '<cmd>ObsidianTOC<CR>', { desc = 'Table of [C]ontent' })
vim.keymap.set('n', '<leader>ob', '<cmd>ObsidianBacklinks<CR>', { desc = '[B]acklinks' })
vim.keymap.set('n', '<leader>oi', '<cmd>ObsidianLinks<CR>', { desc = 'L[i]nks' })
vim.keymap.set('n', '<leader>or', '<cmd>ObsidianRename<CR>', { desc = '[R]enomer la note' })
vim.keymap.set('n', '<leader>od', '<cmd>DeleteNote<CR>', { desc = '[D]elete note' })
vim.keymap.set('n', '<leader>ov', '<cmd>MoveNoteToAll<CR>', { desc = '[V]alider la note' })
-- visual mode obsidian
vim.keymap.set('v', '<leader>ol', '<cmd>ObsidianLink<CR>', { desc = '[L]ien' })
vim.keymap.set('v', '<leader>oo', '<cmd>ObsidianLinkNew<CR>', { desc = '[O]bs. nouveau lien' })
vim.keymap.set('v', '<leader>oe', '<cmd>ObsidianExtractNote<CR>', { desc = '[E]xtraire la note' })